@@ -1,13 +1,17 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: topology_physical_info
-short_description: Information module for Topology Physical Info
+short_description: Information module for Topology Physical
 description:
-  - This module represents an alias of the module topology_physical_v1_info
+  - Get all Topology Physical.
+  - Returns the raw physical topology by specified criteria
+    of nodeType.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,19 +25,24 @@ options:
       - NodeType query parameter.
     type: str
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Topology GetPhysicalTopologyV1
-    description: Complete reference of the GetPhysicalTopologyV1 API.
+  - name: Cisco DNA Center documentation for Topology
+      GetPhysicalTopology
+    description: Complete reference of the GetPhysicalTopology
+      API.
     link: https://developer.cisco.com/docs/dna-center/#!get-physical-topology
 notes:
-  - SDK Method used are topology.Topology.get_physical_topology_v1,
-  - Paths used are get /dna/intent/api/v1/topology/physical-topology,
-  - It should be noted that this module is an alias of topology_physical_v1_info
+  - SDK Method used are
+    topology.Topology.get_physical_topology,
+  - Paths used are
+    get /dna/intent/api/v1/topology/physical-topology,
 """
+
 EXAMPLES = r"""
-- name: Get all Topology Physical Info
+---
+- name: Get all Topology Physical
   cisco.dnac.topology_physical_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
