@@ -19,8 +19,7 @@ created.
 """
 
 
-from ansible.module_utils.six import iteritems
-from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.resource_module import (
+from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.resource_module import (
     ResourceModule,
 )
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.utils import (
@@ -75,16 +74,16 @@ class Prefix_lists(ResourceModule):
 
         # if state is deleted, empty out wantd and set haved to wantd
         if self.state == "deleted":
-            haved = {k: v for k, v in iteritems(haved) if k in wantd or not wantd}
+            haved = {k: v for k, v in haved.items() if k in wantd or not wantd}
             wantd = {}
 
         # remove superfluous config for overridden and deleted
         if self.state in ["overridden", "deleted"]:
-            for k, have in iteritems(haved):
+            for k, have in haved.items():
                 if k not in wantd:
                     self._compare(want={}, have=have)
 
-        for k, want in iteritems(wantd):
+        for k, want in wantd.items():
             self._compare(want=want, have=haved.pop(k, {}))
             # alligning cmd with negate cmd 1st followed by config cmd
         if self.state in ["overridden", "replaced"]:
@@ -104,7 +103,7 @@ class Prefix_lists(ResourceModule):
         )
 
     def _compare_plists(self, want, have):
-        for wk, wentry in iteritems(want):
+        for wk, wentry in want.items():
             hentry = have.pop(wk, {})
             # compare sequences
             self._compare_seqs(
@@ -119,7 +118,7 @@ class Prefix_lists(ResourceModule):
             )
 
     def _compare_seqs(self, want, have):
-        for wseq, wentry in iteritems(want):
+        for wseq, wentry in want.items():
             hentry = have.pop(wseq, {})
             self.compare(parsers=self.parsers, want=wentry, have=hentry)
 
@@ -128,7 +127,7 @@ class Prefix_lists(ResourceModule):
             self.compare(parsers=self.parsers, want={}, have=hseq)
 
     def _prefix_list_to_dict(self, entry):
-        for afi, value in iteritems(entry):
+        for afi, value in entry.items():
             if "prefix_lists" in value:
                 for plist in value["prefix_lists"]:
                     plist.update({"afi": afi})
