@@ -134,7 +134,7 @@ def gitlab_authentication(module, min_version=None):
 def filter_returned_variables(gitlab_variables):
     # pop properties we don't know
     existing_variables = [dict(x.attributes) for x in gitlab_variables]
-    KNOWN = ['key', 'value', 'masked', 'protected', 'variable_type', 'environment_scope', 'raw']
+    KNOWN = ['key', 'value', 'description', 'masked', 'hidden', 'protected', 'variable_type', 'environment_scope', 'raw']
     for item in existing_variables:
         for key in list(item.keys()):
             if key not in KNOWN:
@@ -151,8 +151,10 @@ def vars_to_variables(vars, module):
                 {
                     "name": item,
                     "value": str(value),
+                    "description": None,
                     "masked": False,
                     "protected": False,
+                    "hidden": False,
                     "raw": False,
                     "variable_type": "env_var",
                 }
@@ -162,7 +164,9 @@ def vars_to_variables(vars, module):
             new_item = {
                 "name": item,
                 "value": value.get('value'),
+                "description": value.get('description'),
                 "masked": value.get('masked'),
+                "hidden": value.get('hidden'),
                 "protected": value.get('protected'),
                 "raw": value.get('raw'),
                 "variable_type": value.get('variable_type'),
