@@ -260,7 +260,7 @@ from ansible_collections.community.vmware.plugins.module_utils.vmware import (
     option_diff,
 )
 from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
-from ansible.module_utils._text import to_native
+from ansible.module_utils.common.text.converters import to_native
 
 
 class VMwareCluster(PyVmomi):
