@@ -164,6 +164,7 @@ import uuid
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.community.vmware.plugins.module_utils.vmware_rest_client import VmwareRestClient
 from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import rest_compatible_argument_spec
 
 HAS_VAUTOMATION_PYTHON_SDK = False
 try:
@@ -414,7 +415,7 @@ class VmwareContentLibCreate(VmwareRestClient):
 
 
 def main():
-    argument_spec = VmwareRestClient.vmware_client_argument_spec()
+    argument_spec = rest_compatible_argument_spec()
     argument_spec.update(
         library_name=dict(type='str', required=True),
         library_description=dict(type='str', required=False),
