@@ -188,7 +188,7 @@ except ImportError:
     pass
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils._text import to_native
+from ansible.module_utils.common.text.converters import to_native
 from ansible_collections.community.vmware.plugins.module_utils.vmware import (
     PyVmomi, TaskError, find_dvs_by_name, wait_for_task
 )
