@@ -17,7 +17,6 @@ short_description: Manage association of VMware tags with VMware objects
 description:
 - This module can be used to assign / remove VMware tags from the given VMware objects.
 - Tag feature is introduced in vSphere 6 version, so this module is not supported in the earlier versions of vSphere.
-- All variables and VMware object names are case sensitive.
 author:
 - Abhijeet Kasurde (@Akasurde)
 - Frederic Van Reet (@GBrawl)
@@ -29,23 +28,23 @@ options:
       - List of tag(s) to be managed.
       - User can also specify category name by specifying colon separated value. For example, "category_name:tag_name".
       - User can also specify tag and category as dict, when tag or category contains colon.
-        See example for more information. Added in version 2.10.
+        See example for more information.
       - User can skip category name if you have unique tag names.
-      required: True
+      required: true
       type: list
       elements: raw
     state:
       description:
-      - If C(state) is set to C(add) or C(present) will add the tags to the existing tag list of the given object.
-      - If C(state) is set to C(remove) or C(absent) will remove the tags from the existing tag list of the given object.
-      - If C(state) is set to C(set) will replace the tags of the given objects with the user defined list of tags.
+      - If set to V(add) or V(present) will add the tags to the existing tag list of the given object.
+      - If set to V(remove) or V(absent) will remove the tags from the existing tag list of the given object.
+      - If set to V(set) will replace the tags of the given objects with the user defined list of tags.
       default: add
       choices: [ present, absent, add, remove, set ]
       type: str
     object_type:
       description:
       - Type of object to work with.
-      required: True
+      required: true
       choices:
         - VirtualMachine
         - Datacenter
@@ -62,14 +61,14 @@ options:
       description:
       - Name of the object to work with.
       - For DistributedVirtualPortgroups the format should be "switch_name:portgroup_name"
-      - Required if C(moid) is not set.
-      required: False
+      - Required if O(moid) is not set.
+      required: false
       type: str
     moid:
       description:
       - Managed object ID for the given object.
-      - Required if C(object_name) is not set.
-      required: False
+      - Required if O(object_name) is not set.
+      required: false
       type: str
 extends_documentation_fragment:
 - community.vmware.vmware_rest_client.documentation
@@ -173,22 +172,23 @@ tag_status:
     returned: on success
     type: list
     sample: {
+        "attached_tags": [
+            "urn:vmomi:InventoryServiceCategory:76f69e84-f6b9-4e64-954c-fac545d2c0ba:GLOBAL:security",
+        ],
         "current_tags": [
-            "backup",
-            "security"
-        ],
-        "desired_tags": [
-            "security"
+            "urn:vmomi:InventoryServiceCategory:927f5ff8-62e6-4364-bc94-23e3bfd7dee7:GLOBAL:backup",
+            "urn:vmomi:InventoryServiceCategory:76f69e84-f6b9-4e64-954c-fac545d2c0ba:GLOBAL:security",
         ],
+        "detached_tags": [],
         "previous_tags": [
-            "backup",
-            "security"
+            "urn:vmomi:InventoryServiceCategory:927f5ff8-62e6-4364-bc94-23e3bfd7dee7:GLOBAL:backup",
         ]
     }
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.community.vmware.plugins.module_utils.vmware_rest_client import VmwareRestClient
 from ansible_collections.community.vmware.plugins.module_utils.vmware import (PyVmomi, find_dvs_by_name, find_dvspg_by_name)
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import rest_compatible_argument_spec
 try:
     from com.vmware.vapi.std_client import DynamicID
     from com.vmware.vapi.std.errors_client import Error
@@ -208,7 +208,7 @@ class VmwareTagManager(VmwareRestClient):
         self.object_type = self.params.get('object_type')
         managed_object_id = None
 
-        if moid:
+        if moid is not None:
             managed_object_id = moid
         else:
             object_name = self.params.get('object_name')
@@ -282,19 +282,20 @@ class VmwareTagManager(VmwareRestClient):
             changed=False,
             tag_status=dict(),
         )
-        tag_objs = []
+        desired_tag_objs = set()
         changed = False
         action = self.params.get('state')
         try:
-            available_tag_obj = self.get_tags_for_object(tag_service=self.tag_service,
-                                                         tag_assoc_svc=self.tag_association_svc,
-                                                         dobj=self.dynamic_managed_object)
+            current_tag_objs = self.get_tags_for_object(tag_service=self.tag_service,
+                                                        tag_assoc_svc=self.tag_association_svc,
+                                                        dobj=self.dynamic_managed_object,
+                                                        tags=set())
         except Error as error:
             self.module.fail_json(msg="%s" % self.get_error_message(error))
 
-        _temp_prev_tags = ["%s:%s" % (tag['category_name'], tag['name']) for tag in self.get_tags_for_dynamic_obj(self.dynamic_managed_object)]
-        results['tag_status']['previous_tags'] = _temp_prev_tags
-        results['tag_status']['desired_tags'] = self.tag_names
+        results['tag_status']['previous_tags'] = ["%s:%s" % (tag_obj.category_id, tag_obj.name) for tag_obj in current_tag_objs]
+        results['tag_status']['attached_tags'] = []
+        results['tag_status']['detached_tags'] = []
 
         # Check if category and tag combination exists as per user request
         for tag in self.tag_names:
@@ -302,80 +303,99 @@ class VmwareTagManager(VmwareRestClient):
             if isinstance(tag, dict):
                 tag_name = tag.get('tag')
                 category_name = tag.get('category')
-                if category_name:
+                if category_name is not None:
                     # User specified category
                     category_obj = self.search_svc_object_by_name(self.category_service, category_name)
-                    if not category_obj:
+                    if category_obj is None:
                         self.module.fail_json(msg="Unable to find the category %s" % category_name)
             elif isinstance(tag, str):
                 if ":" in tag:
                     # User specified category
                     category_name, tag_name = tag.split(":", 1)
                     category_obj = self.search_svc_object_by_name(self.category_service, category_name)
-                    if not category_obj:
+                    if category_obj is None:
                         self.module.fail_json(msg="Unable to find the category %s" % category_name)
                 else:
                     # User specified only tag
                     tag_name = tag
 
-            if category_obj:
-                tag_obj = self.get_tag_by_category(tag_name=tag_name, category_id=category_obj.id)
-            elif category_name:
-                tag_obj = self.get_tag_by_category(tag_name=tag_name, category_name=category_name)
+            if category_obj is not None:
+                tag_obj = self.get_tag_by_category_id(tag_name=tag_name, category_id=category_obj.id)
             else:
                 tag_obj = self.get_tag_by_name(tag_name=tag_name)
 
-            if not tag_obj:
+            if tag_obj is None:
                 self.module.fail_json(msg="Unable to find the tag %s" % tag_name)
 
-            tag_objs.append(tag_obj)
+            desired_tag_objs.add(tag_obj)
+
+        detached_tag_objs = set()
+        attached_tag_objs = set()
 
         if action in ('add', 'present'):
-            for tag_obj in tag_objs:
-                if tag_obj not in available_tag_obj:
-                    # Tag is not already applied
-                    try:
-                        self.tag_association_svc.attach(tag_id=tag_obj.id, object_id=self.dynamic_managed_object)
-                        changed = True
-                    except Error as error:
-                        self.module.fail_json(msg="%s" % self.get_error_message(error))
+            # Tags that need to be attached
+            tag_objs_to_attach = desired_tag_objs.difference(current_tag_objs)
+            tag_ids_to_attach = [tag_obj.id for tag_obj in tag_objs_to_attach]
+            if len(tag_ids_to_attach) > 0:
+                try:
+                    self.tag_association_svc.attach_multiple_tags_to_object(object_id=self.dynamic_managed_object,
+                                                                            tag_ids=tag_ids_to_attach)
+                    attached_tag_objs.update(tag_objs_to_attach)
+                    current_tag_objs.update(tag_objs_to_attach)
+                    changed = True
+                except Error as error:
+                    self.module.fail_json(msg="%s" % self.get_error_message(error))
 
         elif action == 'set':
-            for av_tag in available_tag_obj:
-                if av_tag not in tag_objs:
-                    # Tag not in the defined list
-                    try:
-                        self.tag_association_svc.detach(tag_id=av_tag.id, object_id=self.dynamic_managed_object)
-                        changed = True
-                    except Error as error:
-                        self.module.fail_json(msg="%s" % self.get_error_message(error))
+            # Tags that need to be detached
+            tag_objs_to_detach = current_tag_objs.difference(desired_tag_objs)
+            tag_ids_to_detach = [tag_obj.id for tag_obj in tag_objs_to_detach]
+            if len(tag_ids_to_detach) > 0:
+                try:
+                    self.tag_association_svc.detach_multiple_tags_from_object(object_id=self.dynamic_managed_object,
+                                                                              tag_ids=tag_ids_to_detach)
+                    detached_tag_objs.update(tag_objs_to_detach)
+                    current_tag_objs.difference_update(tag_objs_to_detach)
+                    changed = True
+                except Error as error:
+                    self.module.fail_json(msg="%s" % self.get_error_message(error))
 
-            for tag_obj in tag_objs:
-                if tag_obj not in available_tag_obj:
-                    # Tag is not already applied
-                    try:
-                        self.tag_association_svc.attach(tag_id=tag_obj.id, object_id=self.dynamic_managed_object)
-                        changed = True
-                    except Error as error:
-                        self.module.fail_json(msg="%s" % self.get_error_message(error))
+            # Tags that need to be attached
+            tag_objs_to_attach = desired_tag_objs.difference(current_tag_objs)
+            tag_ids_to_attach = [tag_obj.id for tag_obj in tag_objs_to_attach]
+            if len(tag_ids_to_attach) > 0:
+                try:
+                    self.tag_association_svc.attach_multiple_tags_to_object(object_id=self.dynamic_managed_object,
+                                                                            tag_ids=tag_ids_to_attach)
+                    attached_tag_objs.update(tag_objs_to_attach)
+                    current_tag_objs.update(tag_objs_to_attach)
+                    changed = True
+                except Error as error:
+                    self.module.fail_json(msg="%s" % self.get_error_message(error))
 
         elif action in ('remove', 'absent'):
-            for tag_obj in tag_objs:
-                if tag_obj in available_tag_obj:
-                    try:
-                        self.tag_association_svc.detach(tag_id=tag_obj.id, object_id=self.dynamic_managed_object)
-                        changed = True
-                    except Error as error:
-                        self.module.fail_json(msg="%s" % self.get_error_message(error))
+            # Tags that need to be detached
+            tag_objs_to_detach = current_tag_objs.intersection(desired_tag_objs)
+            tag_ids_to_detach = [tag_obj.id for tag_obj in tag_objs_to_detach]
+            if len(tag_ids_to_detach) > 0:
+                try:
+                    self.tag_association_svc.detach_multiple_tags_from_object(object_id=self.dynamic_managed_object,
+                                                                              tag_ids=tag_ids_to_detach)
+                    detached_tag_objs.update(tag_objs_to_detach)
+                    current_tag_objs.difference_update(tag_objs_to_detach)
+                    changed = True
+                except Error as error:
+                    self.module.fail_json(msg="%s" % self.get_error_message(error))
 
-        _temp_curr_tags = ["%s:%s" % (tag['category_name'], tag['name']) for tag in self.get_tags_for_dynamic_obj(self.dynamic_managed_object)]
-        results['tag_status']['current_tags'] = _temp_curr_tags
+        results['tag_status']['detached_tags'] = ["%s:%s" % (tag_obj.category_id, tag_obj.name) for tag_obj in detached_tag_objs]
+        results['tag_status']['attached_tags'] = ["%s:%s" % (tag_obj.category_id, tag_obj.name) for tag_obj in attached_tag_objs]
+        results['tag_status']['current_tags'] = ["%s:%s" % (tag_obj.category_id, tag_obj.name) for tag_obj in current_tag_objs]
         results['changed'] = changed
         self.module.exit_json(**results)
 
 
 def main():
-    argument_spec = VmwareRestClient.vmware_client_argument_spec()
+    argument_spec = rest_compatible_argument_spec()
     argument_spec.update(
         tag_names=dict(type='list', required=True, elements='raw'),
         state=dict(type='str', choices=['absent', 'add', 'present', 'remove', 'set'], default='add'),
