@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -243,8 +246,8 @@ EXAMPLES = '''
     - name: Configure POP3S options.
       fortinet.fortimanager.fmgr_firewall_sslsshprofile_pop3s:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -327,6 +330,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'ssl-ssh-profile': {'type': 'str', 'api_name': 'ssl_ssh_profile'},
         'ssl_ssh_profile': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_sslsshprofile_pop3s': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
