@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -121,8 +124,8 @@ EXAMPLES = '''
     - name: Configure consolidated IPv4/IPv6 policies.
       fortinet.fortimanager.fmgr_pkg_firewall_consolidated_policy_sectionvalue:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -189,6 +192,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'pkg': {'required': True, 'type': 'str'},
         'policy': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'pkg_firewall_consolidated_policy_sectionvalue': {
             'type': 'dict',
             'v_range': [['6.2.5', '7.6.2']],
