@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -123,6 +126,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -133,13 +137,13 @@ EXAMPLES = '''
       fortinet.fortimanager.fmgr_system_replacemsggroup_ftp:
         bypass_validation: false
         adom: ansible
-        replacemsg-group: ansible-test # name
+        replacemsg_group: ansible-test # name
         state: present
         system_replacemsggroup_ftp:
           buffer: ansible-buffer
           format: none # <value in [none, text, html, ...]>
           header: http # <value in [none, http, 8bit]>
-          msg-type: ansible-msgtype # required
+          msg_type: ansible-msgtype # required
 
 - name: Gathering fortimanager facts
   hosts: fortimanagers
@@ -156,7 +160,7 @@ EXAMPLES = '''
           selector: "system_replacemsggroup_ftp"
           params:
             adom: "ansible"
-            replacemsg-group: "ansible-test" # name
+            replacemsg_group: "ansible-test" # name
             ftp: "your_value"
 '''
 
@@ -216,6 +220,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'replacemsg-group': {'type': 'str', 'api_name': 'replacemsg_group'},
         'replacemsg_group': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'system_replacemsggroup_ftp': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
