@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -104,6 +107,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -114,7 +118,7 @@ EXAMPLES = '''
       fortinet.fortimanager.fmgr_system_sdnconnector_route:
         bypass_validation: false
         adom: ansible
-        sdn-connector: ansible-test-sdn # name
+        sdn_connector: ansible-test-sdn # name
         state: present
         system_sdnconnector_route: # available only when type is set to 'gcp' in sdn-connector
           name: ansible-test-route
@@ -134,7 +138,7 @@ EXAMPLES = '''
           selector: "system_sdnconnector_route" # available only when type is set to 'gcp' in sdn-connector
           params:
             adom: "ansible"
-            sdn-connector: "ansible-test-sdn" # name
+            sdn_connector: "ansible-test-sdn" # name
             route: "your_value"
 '''
 
@@ -179,34 +183,26 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/system/sdn-connector/{sdn-connector}/route',
         '/pm/config/global/obj/system/sdn-connector/{sdn-connector}/route'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/system/sdn-connector/{sdn-connector}/route/{route}',
-        '/pm/config/global/obj/system/sdn-connector/{sdn-connector}/route/{route}'
-    ]
-
     url_params = ['adom', 'sdn-connector']
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'sdn-connector': {'type': 'str', 'api_name': 'sdn_connector'},
         'sdn_connector': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'system_sdnconnector_route': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
             'options': {'name': {'required': True, 'type': 'str'}}
-
         }
     }
 
@@ -220,9 +216,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
