@@ -21,7 +21,7 @@ options:
               the specified time.
             - You can choose seconds, minutes, hours, days or weeks
               by specifying the first letter of an of
-              those words (e.g., "2s", "10d", 1w").
+              those words (for example, "2s", "10d", 1w").
         type: str
     age_stamp:
         description:
@@ -45,9 +45,11 @@ options:
         type: int
         version_added: 2.0.0
     file_type:
-        description: Type of file to search for.
+        description:
+            - Type of file to search for.
+            - Specify V(any) to find both file and directory. Added in version 3.2.0.
         type: str
-        choices: [ directory, file ]
+        choices: [ directory, file, any ]
         default: file
     follow:
         description:
@@ -98,6 +100,13 @@ options:
             - Will set patterns to run as a regex check if set to C(true).
         type: bool
         default: no
+    case_sensitive:
+        description:
+            - Make case-sensitive string comparisons for the filename match.
+            - Set C(use_regex) to V(true) to make this work.
+        type: bool
+        default: no
+        version_added: 3.0.0
 notes:
 - When scanning directories with a large number of files containing lots of data it is recommended to set
   C(get_checksum=false). This will speed up the time it takes to scan the folders as getting a checksum needs to
@@ -119,8 +128,8 @@ EXAMPLES = r'''
 - name: Find files in multiple paths
   ansible.windows.win_find:
     paths:
-    - C:\Temp
-    - D:\Temp
+      - C:\Temp
+      - D:\Temp
 
 - name: Find files in directory while searching recursively
   ansible.windows.win_find:
@@ -136,7 +145,7 @@ EXAMPLES = r'''
 - name: Find files with .log and .out extension using powershell wildcards
   ansible.windows.win_find:
     paths: D:\Temp
-    patterns: [ '*.log', '*.out' ]
+    patterns: ['*.log', '*.out']
 
 - name: Find files in path based on regex pattern
   ansible.windows.win_find:
@@ -192,8 +201,8 @@ EXAMPLES = r'''
 - name: Find folders/symlinks in multiple paths
   ansible.windows.win_find:
     paths:
-    - C:\Temp
-    - D:\Temp
+      - C:\Temp
+      - D:\Temp
     file_type: directory
 
 - name: Find files and return SHA256 checksum of files found
