@@ -17,120 +17,108 @@ description:
      - Manage I(libvirt) networks.
 options:
     name:
-        required: False
         aliases: ['network']
         description:
-            - name of the network being managed. Note that network must be previously
+            - Name of the network being managed. Note that network must be previously
               defined with xml.
         type: str
     state:
-        required: False
         choices: [ "active", "inactive", "present", "absent" ]
         description:
-            - specify which state you want a network to be in.
+            - Specify which state you want a network to be in.
               If 'active', network will be started.
               If 'present', ensure that network is present but do not change its
-              state; if it's missing, you need to specify xml argument.
+              state; if it is missing, you need to specify xml argument.
               If 'inactive', network will be stopped.
               If 'undefined' or 'absent', network will be removed from I(libvirt) configuration.
         type: str
     command:
-        required: False
         choices: [ "define", "create", "start", "stop", "destroy",
                    "undefine", "get_xml", "list_nets", "facts",
                    "info", "status", "modify"]
         description:
-            - in addition to state management, various non-idempotent commands are available.
+            - In addition to state management, various non-idempotent commands are available.
               See examples.
-              Modify was added in version 2.1
+              Modify was added in Ansible version 2.1.
         type: str
     autostart:
-        required: False
         type: bool
         description:
             - Specify if a given network should be started automatically on system boot.
-    uri:
-        required: False
-        default: "qemu:///system"
-        description:
-            - libvirt connection uri.
-        type: str
-    xml:
-        required: False
-        description:
-            - XML document used with the define command.
-        type: str
+extends_documentation_fragment:
+    - community.libvirt.virt.options_uri
+    - community.libvirt.virt.options_xml
+    - community.libvirt.requirements
 requirements:
-    - "python >= 2.6"
-    - "python-libvirt"
     - "python-lxml"
 '''
 
 EXAMPLES = '''
-# Define a new network
-- community.libvirt.virt_net:
+- name: Define a new network
+  community.libvirt.virt_net:
     command: define
     name: br_nat
     xml: '{{ lookup("template", "network/bridge.xml.j2") }}'
 
-# Start a network
-- community.libvirt.virt_net:
+- name: Start a network
+  community.libvirt.virt_net:
     command: create
     name: br_nat
 
-# List available networks
-- community.libvirt.virt_net:
+- name: List available networks
+  community.libvirt.virt_net:
     command: list_nets
 
-# Get XML data of a specified network
-- community.libvirt.virt_net:
+- name: Get XML data of a specified network
+  community.libvirt.virt_net:
     command: get_xml
     name: br_nat
 
-# Stop a network
-- community.libvirt.virt_net:
+- name: Stop a network
+  community.libvirt.virt_net:
     command: destroy
     name: br_nat
 
-# Undefine a network
-- community.libvirt.virt_net:
+- name: Undefine a network
+  community.libvirt.virt_net:
     command: undefine
     name: br_nat
 
 # Gather facts about networks
 # Facts will be available as 'ansible_libvirt_networks'
-- community.libvirt.virt_net:
+- name: Gather facts about networks
+  community.libvirt.virt_net:
     command: facts
 
-# Gather information about network managed by 'libvirt' remotely using uri
-- community.libvirt.virt_net:
+- name: Gather information about network managed by 'libvirt' remotely using uri
+  community.libvirt.virt_net:
     command: info
     uri: '{{ item }}'
   with_items: '{{ libvirt_uris }}'
   register: networks
 
-# Ensure that a network is active (needs to be defined and built first)
-- community.libvirt.virt_net:
+- name: Ensure that a network is active (needs to be defined and built first)
+  community.libvirt.virt_net:
     state: active
     name: br_nat
 
-# Ensure that a network is inactive
-- community.libvirt.virt_net:
+- name: Ensure that a network is inactive
+  community.libvirt.virt_net:
     state: inactive
     name: br_nat
 
-# Ensure that a given network will be started at boot
-- community.libvirt.virt_net:
-    autostart: yes
+- name: Ensure that a given network will be started at boot
+  community.libvirt.virt_net:
+    autostart: true
     name: br_nat
 
-# Disable autostart for a given network
-- community.libvirt.virt_net:
-    autostart: no
+- name: Disable autostart for a given network
+  community.libvirt.virt_net:
+    autostart: false
     name: br_nat
 
-# Add a new host in the dhcp pool
-- community.libvirt.virt_net:
+- name: Add a new host in the dhcp pool
+  community.libvirt.virt_net:
     name: br_nat
     command: modify
     xml: "<host mac='FC:C2:33:00:6c:3c' name='my_vm' ip='192.168.122.30'/>"
@@ -239,9 +227,14 @@ class LibvirtConnection(object):
             if host is None:
                 # add the host
                 if not self.module.check_mode:
-                    res = network.update(libvirt.VIR_NETWORK_UPDATE_COMMAND_ADD_LAST,
-                                         libvirt.VIR_NETWORK_SECTION_IP_DHCP_HOST,
-                                         -1, xml, libvirt.VIR_NETWORK_UPDATE_AFFECT_CURRENT)
+                    if network.isActive():
+                        res = network.update(libvirt.VIR_NETWORK_UPDATE_COMMAND_ADD_LAST,
+                                             libvirt.VIR_NETWORK_SECTION_IP_DHCP_HOST,
+                                             -1, xml, libvirt.VIR_NETWORK_UPDATE_AFFECT_LIVE | libvirt.VIR_NETWORK_UPDATE_AFFECT_CONFIG)
+                    else:
+                        res = network.update(libvirt.VIR_NETWORK_UPDATE_COMMAND_ADD_LAST,
+                                             libvirt.VIR_NETWORK_SECTION_IP_DHCP_HOST,
+                                             -1, xml, libvirt.VIR_NETWORK_UPDATE_AFFECT_CONFIG)
                 else:
                     # pretend there was a change
                     res = 0
@@ -253,9 +246,14 @@ class LibvirtConnection(object):
                     return False
                 else:
                     if not self.module.check_mode:
-                        res = network.update(libvirt.VIR_NETWORK_UPDATE_COMMAND_MODIFY,
-                                             libvirt.VIR_NETWORK_SECTION_IP_DHCP_HOST,
-                                             -1, xml, libvirt.VIR_NETWORK_UPDATE_AFFECT_CURRENT)
+                        if network.isActive():
+                            res = network.update(libvirt.VIR_NETWORK_UPDATE_COMMAND_MODIFY,
+                                                 libvirt.VIR_NETWORK_SECTION_IP_DHCP_HOST,
+                                                 -1, xml, libvirt.VIR_NETWORK_UPDATE_AFFECT_LIVE | libvirt.VIR_NETWORK_UPDATE_AFFECT_CONFIG)
+                        else:
+                            res = network.update(libvirt.VIR_NETWORK_UPDATE_COMMAND_MODIFY,
+                                                 libvirt.VIR_NETWORK_SECTION_IP_DHCP_HOST,
+                                                 -1, xml, libvirt.VIR_NETWORK_UPDATE_AFFECT_CONFIG)
                     else:
                         # pretend there was a change
                         res = 0
