@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-# (c) 2018-2023, NetApp, Inc
+# (c) 2018-2025, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
@@ -12,7 +12,7 @@ ANSIBLE_METADATA = {'metadata_version': '1.1',
 
 DOCUMENTATION = '''
 short_description: NetApp ONTAP manage consistency group snapshot
-author: NetApp Ansible Team (@carchi8py) <ng-ansibleteam@netapp.com>
+author: NetApp Ansible Team (@carchi8py) <ng-ansible-team@netapp.com>
 description:
   - Create or delete consistency group snapshot for ONTAP volumes.
 extends_documentation_fragment:
@@ -67,6 +67,14 @@ options:
       - Only supported with REST.
     type: str
     version_added: 22.8.0
+  consistency_type:
+    description:
+      - Type of consistency guarantee for the snapshot.
+      - Only supported with REST.
+    choices: ['crash', 'application']
+    type: str
+    default: crash
+    version_added: 23.2.0
 version_added: 2.7.0
 
 notes:
@@ -76,49 +84,52 @@ notes:
 '''
 
 EXAMPLES = """
-    - name:
-      na_ontap_cg_snapshot:
-        state: present
-        vserver: vserver_name
-        snapshot: snapshot name
-        volumes: vol_name
-        username: "{{ netapp username }}"
-        password: "{{ netapp password }}"
-        hostname: "{{ netapp hostname }}"
+- name: Create CG snapshot
+  na_ontap_cg_snapshot:
+    state: present
+    vserver: vserver_name
+    snapshot: snapshot name
+    volumes: vol_name
+    # consistency_type defaults to 'crash' if not specified
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    hostname: "{{ netapp_hostname }}"
 
-    - name: Create CG snapshot using CG name - REST
-      na_ontap_cg_snapshot:
-        state: present
-        vserver: vserver_name
-        snapshot: snapshot_name
-        consistency_group: cg_name
-        snapmirror_label: sm_label
-        username: "{{ netapp username }}"
-        password: "{{ netapp password }}"
-        hostname: "{{ netapp hostname }}"
+- name: Create CG snapshot using CG name - REST
+  na_ontap_cg_snapshot:
+    state: present
+    vserver: vserver_name
+    snapshot: snapshot_name
+    consistency_group: cg_name
+    snapmirror_label: sm_label
+    consistency_type: application
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    hostname: "{{ netapp_hostname }}"
 
-    - name: Create CG snapshot using volumes - REST
-      na_ontap_cg_snapshot:
-        state: present
-        vserver: vserver_name
-        snapshot: snapshot_name
-        volumes:
-          - vol1
-          - vol2
-        snapmirror_label: sm_label
-        username: "{{ netapp username }}"
-        password: "{{ netapp password }}"
-        hostname: "{{ netapp hostname }}"
+- name: Create CG snapshot using volumes - REST
+  na_ontap_cg_snapshot:
+    state: present
+    vserver: vserver_name
+    snapshot: snapshot_name
+    volumes:
+      - vol1
+      - vol2
+    snapmirror_label: sm_label
+    consistency_type: crash
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    hostname: "{{ netapp_hostname }}"
 
-    - name: Delete CG snapshot - REST
-      na_ontap_cg_snapshot:
-        state: absent
-        vserver: vserver_name
-        snapshot: snapshot_name
-        consistency_group: cg_name
-        username: "{{ netapp username }}"
-        password: "{{ netapp password }}"
-        hostname: "{{ netapp hostname }}"
+- name: Delete CG snapshot - REST
+  na_ontap_cg_snapshot:
+    state: absent
+    vserver: vserver_name
+    snapshot: snapshot_name
+    consistency_group: cg_name
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    hostname: "{{ netapp_hostname }}"
 """
 
 RETURN = """
@@ -150,6 +161,7 @@ class NetAppONTAPCGSnapshot(object):
             snapmirror_label=dict(required=False, type='str'),
             consistency_group=dict(required=False, type='str'),
             comment=dict(required=False, type='str'),
+            consistency_type=dict(required=False, type='str', choices=['crash', 'application'], default='crash'),
         ))
 
         self.module = AnsibleModule(
@@ -267,7 +279,7 @@ class NetAppONTAPCGSnapshot(object):
                                   exception=traceback.format_exc())
 
     def zapi_errors(self):
-        unsupported_zapi_properties = ['consistency_group', 'comment']
+        unsupported_zapi_properties = ['consistency_group', 'comment', 'consistency_type']
         used_unsupported_zapi_properties = [option for option in unsupported_zapi_properties if option in self.parameters]
         if used_unsupported_zapi_properties:
             self.module.fail_json(msg="Error: %s options supported only with REST." % " ,".join(used_unsupported_zapi_properties))
@@ -299,13 +311,13 @@ class NetAppONTAPCGSnapshot(object):
             query['fields'] += 'volumes.name,'
             records, error = rest_generic.get_0_or_more_records(self.rest_api, api, query)
             if error:
-                self.module.fail_json(msg='Error searching for consistency group having volumes %s: %s' % (self.parameters['volumes'], to_native(error)),
+                self.module.fail_json(msg='Error searching for consistency group having volumes %s: %s' % (set(self.parameters['volumes']), to_native(error)),
                                       exception=traceback.format_exc())
             if records:
                 for record in records:
                     if record.get('volumes') is not None:
                         cg_volumes = [vol_item['name'] for vol_item in record['volumes']]
-                        if cg_volumes == self.parameters['volumes']:
+                        if sorted(cg_volumes) == sorted(set(self.parameters['volumes'])):
                             self.cg_uuid = record.get('uuid')
                             break
         return None
@@ -327,7 +339,8 @@ class NetAppONTAPCGSnapshot(object):
                            'uuid,'
                            'consistency_group,'
                            'snapmirror_label,'
-                           'comment,'}
+                           'comment,'
+                           'consistency_type,'}
         record, error = rest_generic.get_one_record(self.rest_api, api, query)
         if error:
             self.module.fail_json(msg='Error searching for consistency group snapshot %s: %s' % (self.parameters['snapshot'], to_native(error)),
@@ -339,6 +352,7 @@ class NetAppONTAPCGSnapshot(object):
                 'consistency_group': self.na_helper.safe_get(record, ['consistency_group', 'name']),
                 'snapmirror_label': record.get('snapmirror_label'),
                 'comment': record.get('comment'),
+                'consistency_type': record.get('consistency_type'),
             }
         return None
 
@@ -350,6 +364,8 @@ class NetAppONTAPCGSnapshot(object):
             body['snapmirror_label'] = self.parameters['snapmirror_label']
         if self.parameters.get('comment'):
             body['comment'] = self.parameters['comment']
+        if self.parameters.get('consistency_type'):
+            body['consistency_type'] = self.parameters['consistency_type']
         dummy, error = rest_generic.post_async(self.rest_api, api, body)
         if error:
             self.module.fail_json(msg='Error creating consistency group snapshot %s: %s' % (self.parameters['snapshot'], to_native(error)),
